==> intel-cmt-cat_23.08.orig.tar.xz: intel-cmt-cat-23.08/appqos_client/src/app/components/system-caps/rdt-iface/rdt-iface.component.spec.ts <==
/*BSD LICENSE

Copyright(c) 2022 Intel Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
  * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.
  * Neither the name of Intel Corporation nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
    
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.*/

import { MockBuilder, MockInstance, MockRender, ngMocks } from 'ng-mocks';
import { TestbedHarnessEnvironment } from '@angular/cdk/testing/testbed';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { fakeAsync } from '@angular/core/testing';

import {
  MatButtonToggleGroupHarness,
  MatButtonToggleHarness,
} from '@angular/material/button-toggle/testing';

import { SharedModule } from 'src/app/shared/shared.module';
import { RDTIface } from '../system-caps.model';
import { RdtIfaceComponent } from './rdt-iface.component';

describe('Given RdtIfaceComponent', () => {
  beforeEach(() =>
    MockBuilder(RdtIfaceComponent)
      .mock(SharedModule)
      .keep(MatButtonToggleModule)
  );

  MockInstance.scope('case');

  describe('when initialized', () => {
    it('should display "RDT Interface selected" title', () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const expectValue = ngMocks.formatText(ngMocks.find('div'));

      expect(expectValue).toEqual('RDT Interface selected');
    });
  });

  describe('when initialized and ONE RDT interface is supported', () => {
    it('should disable toggle button', async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr'],
      };

      const fixture = MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);

      expect(await group.isDisabled()).toBe(true);
    });
  });

  describe('when initialized and Supported RDT interfaces', () => {
    it('should display a toggle group with correct options', async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      const fixture = MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);
      const toggles = await group.getToggles();

      const lables = await Promise.all(
        toggles.map(
          async (toggle: MatButtonToggleHarness) => await toggle.getText()
        )
      );

      expect(lables).toEqual(['msr', 'os']);
    });
  });

  describe('when button toggle is clicked', () => {
    it('should emit "onChange" event with correct value', fakeAsync(async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      const fixture = MockRender(RdtIfaceComponent, { rdtIface: mockedRDT });
      const component = fixture.point.componentInstance;

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);
      const toggles = await group.getToggles();
      const osButton = toggles[1];

      component.changeEvent.subscribe((event) => {
        expect(event.value).toEqual('os');
      });

      await osButton.check();
    }));
  });
});

==> intel-cmt-cat_24.05.orig.tar.xz: intel-cmt-cat-24.05/appqos_client/src/app/components/system-caps/rdt-iface/rdt-iface.component.spec.ts <==
/*BSD LICENSE

Copyright(c) 2022 Intel Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
  * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.
  * Neither the name of Intel Corporation nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.
    
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.*/

import { MockBuilder, MockInstance, MockRender, ngMocks } from 'ng-mocks';
import { TestbedHarnessEnvironment } from '@angular/cdk/testing/testbed';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { fakeAsync } from '@angular/core/testing';

import {
  MatButtonToggleGroupHarness,
  MatButtonToggleHarness,
} from '@angular/material/button-toggle/testing';

import { SharedModule } from 'src/app/shared/shared.module';
import { RDTIface } from '../system-caps.model';
import { RdtIfaceComponent } from './rdt-iface.component';

describe('Given RdtIfaceComponent', () => {
  beforeEach(() =>
    MockBuilder(RdtIfaceComponent)
      .mock(SharedModule)
      .keep(MatButtonToggleModule)
  );

  MockInstance.scope('case');

  describe('when initialized', () => {
    it('should display "RDT Interface selected" title', () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const expectValue = ngMocks.formatText(ngMocks.find('div'));

      expect(expectValue).toEqual('RDT Interface selected');
    });
  });

  describe('when initialized and ONE RDT interface is supported', () => {
    it('should disable toggle button', async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr'],
      };

      const fixture = MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);

      expect(await group.isDisabled()).toBe(true);
    });
  });

  describe('when initialized and Supported RDT interfaces', () => {
    it('should display a toggle group with correct options', async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      const fixture = MockRender(RdtIfaceComponent, {
        rdtIface: mockedRDT,
      });

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);
      const toggles = await group.getToggles();

      const labels = await Promise.all(
        toggles.map(
          async (toggle: MatButtonToggleHarness) => await toggle.getText()
        )
      );

      expect(labels).toEqual(['msr', 'os']);
    });
  });

  describe('when button toggle is clicked', () => {
    it('should emit "onChange" event with correct value', fakeAsync(async () => {
      const mockedRDT: RDTIface = {
        interface: 'msr',
        interface_supported: ['msr', 'os'],
      };

      const fixture = MockRender(RdtIfaceComponent, { rdtIface: mockedRDT });
      const component = fixture.point.componentInstance;

      const loader = TestbedHarnessEnvironment.loader(fixture);
      const group = await loader.getHarness(MatButtonToggleGroupHarness);
      const toggles = await group.getToggles();
      const osButton = toggles[1];

      component.changeEvent.subscribe((event) => {
        expect(event.value).toEqual('os');
      });

      await osButton.check();
    }));
  });
});
